@@ -703,7 +703,11 @@ where
         for (idx, node) in iter.enumerate() {
             emit!(self, node);
 
-            if idx != len - 1 {
+            let is_current_preserved_token = matches!(node, ComponentValue::PreservedToken(_));
+            let next = nodes.get(idx + 1);
+            let is_next_preserved_token = matches!(next, Some(ComponentValue::PreservedToken(_)));
+
+            if idx != len - 1 && !is_current_preserved_token && !is_next_preserved_token {
                 let need_delim = match node {
                     ComponentValue::SimpleBlock(_)
                     | ComponentValue::Function(_)
@@ -711,14 +715,14 @@ where
                     | ComponentValue::Delimiter(_)
                     | ComponentValue::Str(_)
                     | ComponentValue::Url(_)
-                    | ComponentValue::Percentage(_) => match nodes.get(idx + 1) {
+                    | ComponentValue::Percentage(_) => match next {
                         Some(ComponentValue::Delimiter(Delimiter {
                             value: DelimiterValue::Comma,
                             ..
                         })) => false,
                         _ => !self.config.minify,
                     },
-                    ComponentValue::Ident(_) => match nodes.get(idx + 1) {
+                    ComponentValue::Ident(_) => match next {
                         Some(ComponentValue::SimpleBlock(_))
                         | Some(ComponentValue::Color(Color::HexColor(_)))
                         | Some(ComponentValue::Str(_)) => !self.config.minify,
@@ -753,7 +757,7 @@ where
                         }
                         _ => true,
                     },
-                    _ => match nodes.get(idx + 1) {
+                    _ => match next {
                         Some(ComponentValue::SimpleBlock(_))
                         | Some(ComponentValue::Color(Color::HexColor(_))) => !self.config.minify,
                         Some(ComponentValue::Delimiter(_)) => false,
@@ -954,6 +958,9 @@ where
             ComponentValue::Ratio(n) => emit!(self, n),
             ComponentValue::UnicodeRange(n) => emit!(self, n),
             ComponentValue::Color(n) => emit!(self, n),
+            ComponentValue::AlphaValue(n) => emit!(self, n),
+            ComponentValue::Hue(n) => emit!(self, n),
+            ComponentValue::CmykComponent(n) => emit!(self, n),
             ComponentValue::Delimiter(n) => emit!(self, n),
 
             ComponentValue::CalcSum(n) => emit!(self, n),
@@ -1170,6 +1177,30 @@ where
         }
     }
 
+    #[emitter]
+    fn emit_alpha_value(&mut self, n: &AlphaValue) -> Result {
+        match n {
+            AlphaValue::Number(n) => emit!(self, n),
+            AlphaValue::Percentage(n) => emit!(self, n),
+        }
+    }
+
+    #[emitter]
+    fn emit_hue(&mut self, n: &Hue) -> Result {
+        match n {
+            Hue::Number(n) => emit!(self, n),
+            Hue::Angle(n) => emit!(self, n),
+        }
+    }
+
+    #[emitter]
+    fn emit_cmyk_component(&mut self, n: &CmykComponent) -> Result {
+        match n {
+            CmykComponent::Number(n) => emit!(self, n),
+            CmykComponent::Percentage(n) => emit!(self, n),
+        }
+    }
+
     #[emitter]
     fn emit_delimiter(&mut self, n: &Delimiter) -> Result {
         punct!(self, n.value.as_str());
